' . $langs->trans("TicketsShowCompanyLogo") . ' ';
print '';
if ($conf->use_javascript_ajax) {
- print ajax_constantonoff('TICKETS_SHOW_COMPANY_LOGO');
+ print ajax_constantonoff('TICKET_SHOW_COMPANY_LOGO');
} else {
$arrval = array('0' => $langs->trans("No"), '1' => $langs->trans("Yes"));
- print $form->selectarray("TICKETS_SHOW_COMPANY_LOGO", $arrval, $conf->global->TICKETS_SHOW_COMPANY_LOGO);
+ print $form->selectarray("TICKET_SHOW_COMPANY_LOGO", $arrval, $conf->global->TICKET_SHOW_COMPANY_LOGO);
}
print ' ';
print '';
@@ -426,10 +426,10 @@ print '';
print '' . $langs->trans("TicketsDisableEmail") . ' ';
print '';
if ($conf->use_javascript_ajax) {
- print ajax_constantonoff('TICKETS_DISABLE_ALL_MAILS');
+ print ajax_constantonoff('TICKET_DISABLE_ALL_MAILS');
} else {
$arrval = array('0' => $langs->trans("No"), '1' => $langs->trans("Yes"));
- print $form->selectarray("TICKETS_DISABLE_ALL_MAILS", $arrval, $conf->global->TICKETS_DISABLE_ALL_MAILS);
+ print $form->selectarray("TICKET_DISABLE_ALL_MAILS", $arrval, $conf->global->TICKET_DISABLE_ALL_MAILS);
}
print ' ';
print '';
@@ -441,10 +441,10 @@ print ' ';
print '' . $langs->trans("TicketsLogEnableEmail") . ' ';
print '';
if ($conf->use_javascript_ajax) {
- print ajax_constantonoff('TICKETS_ACTIVATE_LOG_BY_EMAIL');
+ print ajax_constantonoff('TICKET_ACTIVATE_LOG_BY_EMAIL');
} else {
$arrval = array('0' => $langs->trans("No"), '1' => $langs->trans("Yes"));
- print $form->selectarray("TICKETS_ACTIVATE_LOG_BY_EMAIL", $arrval, $conf->global->TICKETS_ACTIVATE_LOG_BY_EMAIL);
+ print $form->selectarray("TICKET_ACTIVATE_LOG_BY_EMAIL", $arrval, $conf->global->TICKET_ACTIVATE_LOG_BY_EMAIL);
}
print ' ';
print '';
@@ -458,10 +458,10 @@ if ($conf->global->MAIN_FEATURES_LEVEL >= 2)
print ' ' . $langs->trans("TicketsEmailAlsoSendToMainAddress") . ' ';
print '';
if ($conf->use_javascript_ajax) {
- print ajax_constantonoff('TICKETS_NOTIFICATION_ALSO_MAIN_ADDRESS');
+ print ajax_constantonoff('TICKET_NOTIFICATION_ALSO_MAIN_ADDRESS');
} else {
$arrval = array('0' => $langs->trans("No"), '1' => $langs->trans("Yes"));
- print $form->selectarray("TICKETS_NOTIFICATION_ALSO_MAIN_ADDRESS", $arrval, $conf->global->TICKETS_NOTIFICATION_ALSO_MAIN_ADDRESS);
+ print $form->selectarray("TICKET_NOTIFICATION_ALSO_MAIN_ADDRESS", $arrval, $conf->global->TICKET_NOTIFICATION_ALSO_MAIN_ADDRESS);
}
print ' ';
print '';
@@ -474,10 +474,10 @@ if ($conf->global->MAIN_FEATURES_LEVEL >= 2)
print ' ' . $langs->trans("TicketsLimitViewAssignedOnly") . ' ';
print '';
if ($conf->use_javascript_ajax) {
- print ajax_constantonoff('TICKETS_LIMIT_VIEW_ASSIGNED_ONLY');
+ print ajax_constantonoff('TICKET_LIMIT_VIEW_ASSIGNED_ONLY');
} else {
$arrval = array('0' => $langs->trans("No"), '1' => $langs->trans("Yes"));
- print $form->selectarray("TICKETS_LIMIT_VIEW_ASSIGNED_ONLY", $arrval, $conf->global->TICKETS_LIMIT_VIEW_ASSIGNED_ONLY);
+ print $form->selectarray("TICKET_LIMIT_VIEW_ASSIGNED_ONLY", $arrval, $conf->global->TICKET_LIMIT_VIEW_ASSIGNED_ONLY);
}
print ' ';
print '';
@@ -494,10 +494,10 @@ if (!$conf->use_javascript_ajax) {
print ' ' . $langs->trans("TicketsAutoAssignTicket") . ' ';
print '';
if ($conf->use_javascript_ajax) {
- print ajax_constantonoff('TICKETS_AUTO_ASSIGN_USER_CREATE');
+ print ajax_constantonoff('TICKET_AUTO_ASSIGN_USER_CREATE');
} else {
$arrval = array('0' => $langs->trans("No"), '1' => $langs->trans("Yes"));
- print $form->selectarray("TICKETS_AUTO_ASSIGN_USER_CREATE", $arrval, $conf->global->TICKETS_AUTO_ASSIGN_USER_CREATE);
+ print $form->selectarray("TICKET_AUTO_ASSIGN_USER_CREATE", $arrval, $conf->global->TICKET_AUTO_ASSIGN_USER_CREATE);
}
print ' ';
print '';
@@ -533,7 +533,7 @@ if (empty($conf->global->FCKEDITOR_ENABLE_MAIL)) {
// Email d'envoi des notifications
print ' ' . $langs->trans("TicketEmailNotificationFrom") . ' ';
print '';
-print ' ';
+print ' ';
print '';
print $form->textwithpicto('', $langs->trans("TicketEmailNotificationFromHelp"), 1, 'help');
print ' ';
@@ -542,18 +542,18 @@ print ' ';
// Email de réception des notifications
print '' . $langs->trans("TicketEmailNotificationTo") . ' ';
print '';
-print ' ';
+print ' ';
print '';
print $form->textwithpicto('', $langs->trans("TicketEmailNotificationToHelp"), 1, 'help');
print ' ';
print ' ';
// Texte de création d'un ticket
-$mail_mesg_new = $conf->global->TICKETS_MESSAGE_MAIL_NEW ? $conf->global->TICKETS_MESSAGE_MAIL_NEW : $langs->trans('TicketNewEmailBody');
+$mail_mesg_new = $conf->global->TICKET_MESSAGE_MAIL_NEW ? $conf->global->TICKET_MESSAGE_MAIL_NEW : $langs->trans('TicketNewEmailBody');
print '' . $langs->trans("TicketNewEmailBodyLabel") . '';
print ' ';
require_once DOL_DOCUMENT_ROOT . '/core/class/doleditor.class.php';
-$doleditor = new DolEditor('TICKETS_MESSAGE_MAIL_NEW', $mail_mesg_new, '100%', 120, 'dolibarr_mailings', '', false, true, $conf->global->FCKEDITOR_ENABLE_MAIL, ROWS_2, 70);
+$doleditor = new DolEditor('TICKET_MESSAGE_MAIL_NEW', $mail_mesg_new, '100%', 120, 'dolibarr_mailings', '', false, true, $conf->global->FCKEDITOR_ENABLE_MAIL, ROWS_2, 70);
$doleditor->Create();
print ' ';
print '';
@@ -561,11 +561,11 @@ print $form->textwithpicto('', $langs->trans("TicketNewEmailBodyHelp"), 1, 'help
print ' ';
// Texte d'introduction
-$mail_intro = $conf->global->TICKETS_MESSAGE_MAIL_INTRO ? $conf->global->TICKETS_MESSAGE_MAIL_INTRO : $langs->trans('TicketMessageMailIntroText');
+$mail_intro = $conf->global->TICKET_MESSAGE_MAIL_INTRO ? $conf->global->TICKET_MESSAGE_MAIL_INTRO : $langs->trans('TicketMessageMailIntroText');
print '' . $langs->trans("TicketMessageMailIntroLabelAdmin") . '';
print ' ';
require_once DOL_DOCUMENT_ROOT . '/core/class/doleditor.class.php';
-$doleditor = new DolEditor('TICKETS_MESSAGE_MAIL_INTRO', $mail_intro, '100%', 120, 'dolibarr_mailings', '', false, true, $conf->global->FCKEDITOR_ENABLE_MAIL, ROWS_2, 70);
+$doleditor = new DolEditor('TICKET_MESSAGE_MAIL_INTRO', $mail_intro, '100%', 120, 'dolibarr_mailings', '', false, true, $conf->global->FCKEDITOR_ENABLE_MAIL, ROWS_2, 70);
$doleditor->Create();
print ' ';
print '';
@@ -573,11 +573,11 @@ print $form->textwithpicto('', $langs->trans("TicketMessageMailIntroHelpAdmin"),
print ' ';
// Texte de signature
-$mail_signature = $conf->global->TICKETS_MESSAGE_MAIL_SIGNATURE ? $conf->global->TICKETS_MESSAGE_MAIL_SIGNATURE : $langs->trans('TicketMessageMailSignatureText');
+$mail_signature = $conf->global->TICKET_MESSAGE_MAIL_SIGNATURE ? $conf->global->TICKET_MESSAGE_MAIL_SIGNATURE : $langs->trans('TicketMessageMailSignatureText');
print '' . $langs->trans("TicketMessageMailSignatureLabelAdmin") . '';
print ' ';
require_once DOL_DOCUMENT_ROOT . '/core/class/doleditor.class.php';
-$doleditor = new DolEditor('TICKETS_MESSAGE_MAIL_SIGNATURE', $mail_signature, '100%', 120, 'dolibarr_mailings', '', false, true, $conf->global->FCKEDITOR_ENABLE_MAIL, ROWS_2, 70);
+$doleditor = new DolEditor('TICKET_MESSAGE_MAIL_SIGNATURE', $mail_signature, '100%', 120, 'dolibarr_mailings', '', false, true, $conf->global->FCKEDITOR_ENABLE_MAIL, ROWS_2, 70);
$doleditor->Create();
print ' ';
print '';
@@ -589,31 +589,31 @@ print ' ' . $langs->trans("PublicInterface") . ' ';
print " \n";
// Url public interface
-$url_interface = $conf->global->TICKETS_URL_PUBLIC_INTERFACE;
+$url_interface = $conf->global->TICKET_URL_PUBLIC_INTERFACE;
print '' . $langs->trans("TicketUrlPublicInterfaceLabelAdmin") . '';
print ' ';
-print ' ';
+print ' ';
print '';
print '';
print $form->textwithpicto('', $langs->trans("TicketUrlPublicInterfaceHelpAdmin"), 1, 'help');
print ' ';
// Interface topic
-$url_interface = $conf->global->TICKETS_PUBLIC_INTERFACE_TOPIC;
+$url_interface = $conf->global->TICKET_PUBLIC_INTERFACE_TOPIC;
print '' . $langs->trans("TicketPublicInterfaceTopicLabelAdmin") . '';
print ' ';
-print ' ';
+print ' ';
print '';
print '';
print $form->textwithpicto('', $langs->trans("TicketPublicInterfaceTopicHelp"), 1, 'help');
print ' ';
// Texte d'accueil homepage
-$public_text_home = $conf->global->TICKETS_PUBLIC_TEXT_HOME ? $conf->global->TICKETS_PUBLIC_TEXT_HOME : $langs->trans('TicketPublicInterfaceTextHome');
+$public_text_home = $conf->global->TICKET_PUBLIC_TEXT_HOME ? $conf->global->TICKET_PUBLIC_TEXT_HOME : $langs->trans('TicketPublicInterfaceTextHome');
print '' . $langs->trans("TicketPublicInterfaceTextHomeLabelAdmin") . '';
print ' ';
require_once DOL_DOCUMENT_ROOT . '/core/class/doleditor.class.php';
-$doleditor = new DolEditor('TICKETS_PUBLIC_TEXT_HOME', $public_text_home, '100%', 180, 'dolibarr_notes', '', false, true, $conf->global->FCKEDITOR_ENABLE_SOCIETE, ROWS_2, 70);
+$doleditor = new DolEditor('TICKET_PUBLIC_TEXT_HOME', $public_text_home, '100%', 180, 'dolibarr_notes', '', false, true, $conf->global->FCKEDITOR_ENABLE_SOCIETE, ROWS_2, 70);
$doleditor->Create();
print ' ';
print '';
@@ -621,11 +621,11 @@ print $form->textwithpicto('', $langs->trans("TicketPublicInterfaceTextHomeHelpA
print ' ';
// Texte d'aide à la saisie du message
-$public_text_help_message = $conf->global->TICKETS_PUBLIC_TEXT_HELP_MESSAGE ? $conf->global->TICKETS_PUBLIC_TEXT_HELP_MESSAGE : $langs->trans('TicketPublicPleaseBeAccuratelyDescribe');
+$public_text_help_message = $conf->global->TICKET_PUBLIC_TEXT_HELP_MESSAGE ? $conf->global->TICKET_PUBLIC_TEXT_HELP_MESSAGE : $langs->trans('TicketPublicPleaseBeAccuratelyDescribe');
print '' . $langs->trans("TicketPublicInterfaceTextHelpMessageLabelAdmin") . '';
print ' ';
require_once DOL_DOCUMENT_ROOT . '/core/class/doleditor.class.php';
-$doleditor = new DolEditor('TICKETS_PUBLIC_TEXT_HELP_MESSAGE', $public_text_help_message, '100%', 180, 'dolibarr_notes', '', false, true, $conf->global->FCKEDITOR_ENABLE_SOCIETE, ROWS_2, 70);
+$doleditor = new DolEditor('TICKET_PUBLIC_TEXT_HELP_MESSAGE', $public_text_help_message, '100%', 180, 'dolibarr_notes', '', false, true, $conf->global->FCKEDITOR_ENABLE_SOCIETE, ROWS_2, 70);
$doleditor->Create();
print ' ';
print '';
diff --git a/htdocs/core/class/html.formticket.class.php b/htdocs/core/class/html.formticket.class.php
index de08557890f..1fcc865c05a 100644
--- a/htdocs/core/class/html.formticket.class.php
+++ b/htdocs/core/class/html.formticket.class.php
@@ -327,7 +327,7 @@ class FormTicket
// If public form, display more information
if ($this->ispublic) {
- print '' . ($conf->global->TICKETS_PUBLIC_TEXT_HELP_MESSAGE ? $conf->global->TICKETS_PUBLIC_TEXT_HELP_MESSAGE : $langs->trans('TicketPublicPleaseBeAccuratelyDescribe')) . '
';
+ print '' . ($conf->global->TICKET_PUBLIC_TEXT_HELP_MESSAGE ? $conf->global->TICKET_PUBLIC_TEXT_HELP_MESSAGE : $langs->trans('TicketPublicPleaseBeAccuratelyDescribe')) . '
';
}
include_once DOL_DOCUMENT_ROOT . '/core/class/doleditor.class.php';
$uselocalbrowser = true;
@@ -889,8 +889,8 @@ class FormTicket
}
}
- if ($conf->global->TICKETS_NOTIFICATION_ALSO_MAIN_ADDRESS) {
- $sendto[] = $conf->global->TICKETS_NOTIFICATION_EMAIL_TO . '(generic email)';
+ if ($conf->global->TICKET_NOTIFICATION_ALSO_MAIN_ADDRESS) {
+ $sendto[] = $conf->global->TICKET_NOTIFICATION_EMAIL_TO . '(generic email)';
}
// Print recipient list
@@ -906,7 +906,7 @@ class FormTicket
// Intro
// External users can't send message email
if ($user->rights->ticket->write && !$user->socid) {
- $mail_intro = GETPOST('mail_intro') ? GETPOST('mail_intro') : $conf->global->TICKETS_MESSAGE_MAIL_INTRO;
+ $mail_intro = GETPOST('mail_intro') ? GETPOST('mail_intro') : $conf->global->TICKET_MESSAGE_MAIL_INTRO;
print ' ' . $langs->trans("TicketMessageMailIntro") . ' ';
print '';
@@ -957,7 +957,7 @@ class FormTicket
// Signature
// External users can't send message email
if ($user->rights->ticket->write && !$user->socid) {
- $mail_signature = GETPOST('mail_signature') ? GETPOST('mail_signature') : $conf->global->TICKETS_MESSAGE_MAIL_SIGNATURE;
+ $mail_signature = GETPOST('mail_signature') ? GETPOST('mail_signature') : $conf->global->TICKET_MESSAGE_MAIL_SIGNATURE;
print ' ' . $langs->trans("TicketMessageMailSignature") . ' ';
print '';
diff --git a/htdocs/core/lib/ticket.lib.php b/htdocs/core/lib/ticket.lib.php
index 8f54197113e..7fac65ab42b 100644
--- a/htdocs/core/lib/ticket.lib.php
+++ b/htdocs/core/lib/ticket.lib.php
@@ -150,7 +150,7 @@ function llxHeaderTicket($title, $head = "", $disablejs = 0, $disablehead = 0, $
top_htmlhead($head, $title, $disablejs, $disablehead, $arrayofjs, $arrayofcss); // Show html headers
print '';
- if (! empty($conf->global->TICKETS_SHOW_COMPANY_LOGO)) {
+ if (! empty($conf->global->TICKET_SHOW_COMPANY_LOGO)) {
// Print logo
$urllogo = DOL_URL_ROOT . '/theme/login_logo.png';
@@ -163,8 +163,8 @@ function llxHeaderTicket($title, $head = "", $disablejs = 0, $disablehead = 0, $
$urllogo = DOL_URL_ROOT . '/theme/dolibarr_logo.png';
}
print '';
- print ' ';
- print '' . ($conf->global->TICKETS_PUBLIC_INTERFACE_TOPIC ? $conf->global->TICKETS_PUBLIC_INTERFACE_TOPIC : $langs->trans("TicketSystem")) . ' ';
+ print ' ';
+ print '' . ($conf->global->TICKET_PUBLIC_INTERFACE_TOPIC ? $conf->global->TICKET_PUBLIC_INTERFACE_TOPIC : $langs->trans("TicketSystem")) . ' ';
print ' ';
}
diff --git a/htdocs/core/modules/modTicket.class.php b/htdocs/core/modules/modTicket.class.php
index 9cf2c097e3b..01c10a631ca 100644
--- a/htdocs/core/modules/modTicket.class.php
+++ b/htdocs/core/modules/modTicket.class.php
@@ -107,7 +107,7 @@ class modTicket extends DolibarrModules
// (key, 'chaine', value, desc, visible, 'current' or 'allentities', deleteonunactive)
// Example:
$this->const = array();
- $this->const[1] = array('TICKETS_ENABLE_PUBLIC_INTERFACE', 'chaine', '1', 'Enable ticket public interface');
+ $this->const[1] = array('TICKET_ENABLE_PUBLIC_INTERFACE', 'chaine', '1', 'Enable ticket public interface');
$this->const[2] = array('TICKET_ADDON', 'chaine', 'mod_ticket_simple', 'Ticket ref module');
$this->tabs = array(
diff --git a/htdocs/core/triggers/interface_50_modTicketsup_TicketEmail.class.php b/htdocs/core/triggers/interface_50_modTicket_TicketEmail.class.php
similarity index 92%
rename from htdocs/core/triggers/interface_50_modTicketsup_TicketEmail.class.php
rename to htdocs/core/triggers/interface_50_modTicket_TicketEmail.class.php
index 5c0d2636296..56bbd897f3d 100644
--- a/htdocs/core/triggers/interface_50_modTicketsup_TicketEmail.class.php
+++ b/htdocs/core/triggers/interface_50_modTicket_TicketEmail.class.php
@@ -116,7 +116,7 @@ class InterfaceTicketEmail extends DolibarrTriggers
$res = $userstat->fetch($object->fk_user_assign);
if ($res > 0)
{
- if (empty($conf->global->TICKETS_DISABLE_ALL_MAILS))
+ if (empty($conf->global->TICKET_DISABLE_ALL_MAILS))
{
// Init to avoid errors
$filepath = array();
@@ -146,7 +146,7 @@ class InterfaceTicketEmail extends DolibarrTriggers
$message = dol_nl2br($message);
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$old_MAIN_MAIL_AUTOCOPY_TO = $conf->global->MAIN_MAIL_AUTOCOPY_TO;
$conf->global->MAIN_MAIL_AUTOCOPY_TO = '';
}
@@ -157,7 +157,7 @@ class InterfaceTicketEmail extends DolibarrTriggers
} else {
$result = $mailfile->sendfile();
}
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$conf->global->MAIN_MAIL_AUTOCOPY_TO = $old_MAIN_MAIL_AUTOCOPY_TO;
}
}
@@ -182,9 +182,9 @@ class InterfaceTicketEmail extends DolibarrTriggers
// Send email to notification email
- if (empty($conf->global->TICKETS_DISABLE_ALL_MAILS) && empty($object->context['disableticketemail']))
+ if (empty($conf->global->TICKET_DISABLE_ALL_MAILS) && empty($object->context['disableticketemail']))
{
- $sendto = $conf->global->TICKETS_NOTIFICATION_EMAIL_TO;
+ $sendto = $conf->global->TICKET_NOTIFICATION_EMAIL_TO;
if ($sendto)
{
@@ -217,12 +217,12 @@ class InterfaceTicketEmail extends DolibarrTriggers
$message_admin.=''.$langs->trans('Message').' : '.$object->message.'
';
$message_admin.=''.$langs->trans('SeeThisTicketIntomanagementInterface').'
';
- $from = $conf->global->MAIN_INFO_SOCIETE_NOM.'<'.$conf->global->TICKETS_NOTIFICATION_EMAIL_FROM.'>';
+ $from = $conf->global->MAIN_INFO_SOCIETE_NOM.'<'.$conf->global->TICKET_NOTIFICATION_EMAIL_FROM.'>';
$replyto = $from;
$message_admin = dol_nl2br($message_admin);
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$old_MAIN_MAIL_AUTOCOPY_TO = $conf->global->MAIN_MAIL_AUTOCOPY_TO;
$conf->global->MAIN_MAIL_AUTOCOPY_TO = '';
}
@@ -233,7 +233,7 @@ class InterfaceTicketEmail extends DolibarrTriggers
} else {
$result=$mailfile->sendfile();
}
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$conf->global->MAIN_MAIL_AUTOCOPY_TO = $old_MAIN_MAIL_AUTOCOPY_TO;
}
}
@@ -241,7 +241,7 @@ class InterfaceTicketEmail extends DolibarrTriggers
// Send email to customer
- if (empty($conf->global->TICKETS_DISABLE_ALL_MAILS) && empty($object->context['disableticketemail']) && $object->notify_tiers_at_create)
+ if (empty($conf->global->TICKET_DISABLE_ALL_MAILS) && empty($object->context['disableticketemail']) && $object->notify_tiers_at_create)
{
$sendto = '';
if (empty($user->socid) && empty($user->email)) {
@@ -287,16 +287,16 @@ class InterfaceTicketEmail extends DolibarrTriggers
$message_customer.='';
$message_customer.=''.$langs->trans('Message').' : '.$object->message.'
';
- $url_public_ticket = ($conf->global->TICKETS_URL_PUBLIC_INTERFACE?$conf->global->TICKETS_URL_PUBLIC_INTERFACE.'/':dol_buildpath('/public/ticket/view.php', 2)).'?track_id='.$object->track_id;
+ $url_public_ticket = ($conf->global->TICKET_URL_PUBLIC_INTERFACE?$conf->global->TICKET_URL_PUBLIC_INTERFACE.'/':dol_buildpath('/public/ticket/view.php', 2)).'?track_id='.$object->track_id;
$message_customer.='' . $langs->trans('TicketNewEmailBodyInfosTrackUrlCustomer') . ' : '.$url_public_ticket.'
';
$message_customer.=''.$langs->trans('TicketEmailPleaseDoNotReplyToThisEmail').'
';
- $from = $conf->global->MAIN_INFO_SOCIETE_NOM.'<'.$conf->global->TICKETS_NOTIFICATION_EMAIL_FROM.'>';
+ $from = $conf->global->MAIN_INFO_SOCIETE_NOM.'<'.$conf->global->TICKET_NOTIFICATION_EMAIL_FROM.'>';
$replyto = $from;
$message_customer = dol_nl2br($message_customer);
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$old_MAIN_MAIL_AUTOCOPY_TO = $conf->global->MAIN_MAIL_AUTOCOPY_TO;
$conf->global->MAIN_MAIL_AUTOCOPY_TO = '';
}
@@ -307,7 +307,7 @@ class InterfaceTicketEmail extends DolibarrTriggers
} else {
$result=$mailfile->sendfile();
}
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$conf->global->MAIN_MAIL_AUTOCOPY_TO = $old_MAIN_MAIL_AUTOCOPY_TO;
}
}
diff --git a/htdocs/public/ticket/index.php b/htdocs/public/ticket/index.php
index 96a3980ddd6..bb0499f43e6 100644
--- a/htdocs/public/ticket/index.php
+++ b/htdocs/public/ticket/index.php
@@ -49,11 +49,11 @@ $arrayofjs = array();
$arrayofcss = array('/ticket/css/styles.css.php');
llxHeaderTicket($langs->trans("Tickets"), "", 0, 0, $arrayofjs, $arrayofcss);
-if (!$conf->global->TICKETS_ENABLE_PUBLIC_INTERFACE) {
+if (!$conf->global->TICKET_ENABLE_PUBLIC_INTERFACE) {
print '' . $langs->trans('TicketPublicInterfaceForbidden') . '
';
} else {
print '';
- print '
' . ($conf->global->TICKETS_PUBLIC_TEXT_HOME ? $conf->global->TICKETS_PUBLIC_TEXT_HOME : $langs->trans("TicketPublicDesc")) . '
';
+ print '
' . ($conf->global->TICKET_PUBLIC_TEXT_HOME ? $conf->global->TICKET_PUBLIC_TEXT_HOME : $langs->trans("TicketPublicDesc")) . '
';
print '
';
print '
';
print '
';
diff --git a/htdocs/public/ticket/list.php b/htdocs/public/ticket/list.php
index e5e9b98cec4..d8290849f55 100644
--- a/htdocs/public/ticket/list.php
+++ b/htdocs/public/ticket/list.php
@@ -144,7 +144,7 @@ $arrayofjs = array();
$arrayofcss = array('/ticket/css/styles.css.php');
llxHeaderTicket($langs->trans("Tickets"), "", 0, 0, $arrayofjs, $arrayofcss);
-if (!$conf->global->TICKETS_ENABLE_PUBLIC_INTERFACE) {
+if (!$conf->global->TICKET_ENABLE_PUBLIC_INTERFACE) {
print '
' . $langs->trans('TicketPublicInterfaceForbidden') . '
';
$db->close();
exit();
diff --git a/htdocs/public/ticket/view.php b/htdocs/public/ticket/view.php
index 473a1dfae40..5383133c42e 100644
--- a/htdocs/public/ticket/view.php
+++ b/htdocs/public/ticket/view.php
@@ -133,7 +133,7 @@ $arrayofcss = array('/ticket/css/styles.css.php');
llxHeaderTicket($langs->trans("Tickets"), "", 0, 0, $arrayofjs, $arrayofcss);
-if (!$conf->global->TICKETS_ENABLE_PUBLIC_INTERFACE) {
+if (!$conf->global->TICKET_ENABLE_PUBLIC_INTERFACE) {
print '
' . $langs->trans('TicketPublicInterfaceForbidden') . '
';
$db->close();
exit();
diff --git a/htdocs/ticket/card.php b/htdocs/ticket/card.php
index 9207ea02860..78337253b1b 100644
--- a/htdocs/ticket/card.php
+++ b/htdocs/ticket/card.php
@@ -166,7 +166,7 @@ if ($action == 'view' || $action == 'add_message' || $action == 'close' || $acti
if ($res > 0) {
// or for unauthorized internals users
- if (!$user->societe_id && ($conf->global->TICKETS_LIMIT_VIEW_ASSIGNED_ONLY && $object->fk_user_assign != $user->id) && !$user->rights->ticket->manage) {
+ if (!$user->societe_id && ($conf->global->TICKET_LIMIT_VIEW_ASSIGNED_ONLY && $object->fk_user_assign != $user->id) && !$user->rights->ticket->manage) {
accessforbidden('', 0);
}
@@ -271,7 +271,7 @@ if ($action == 'view' || $action == 'add_message' || $action == 'close' || $acti
dol_fiche_end();
}
- if (!$user->societe_id && $conf->global->TICKETS_LIMIT_VIEW_ASSIGNED_ONLY) {
+ if (!$user->societe_id && $conf->global->TICKET_LIMIT_VIEW_ASSIGNED_ONLY) {
$object->next_prev_filter = "te.fk_user_assign = '" . $user->id . "'";
} elseif ($user->societe_id > 0) {
$object->next_prev_filter = "te.fk_soc = '" . $user->societe_id . "'";
diff --git a/htdocs/ticket/class/ticket.class.php b/htdocs/ticket/class/ticket.class.php
index 1882904ab46..de7f39049f8 100644
--- a/htdocs/ticket/class/ticket.class.php
+++ b/htdocs/ticket/class/ticket.class.php
@@ -1525,7 +1525,7 @@ class Ticket extends CommonObject
dol_syslog(get_class($this) . "::create_ticket_log sql=" . $sql, LOG_DEBUG);
$resql = $this->db->query($sql);
if ($resql) {
- if ($conf->global->TICKETS_ACTIVATE_LOG_BY_EMAIL && !$noemail) {
+ if ($conf->global->TICKET_ACTIVATE_LOG_BY_EMAIL && !$noemail) {
$this->sendLogByEmail($user, $message);
}
@@ -1591,14 +1591,14 @@ class Ticket extends CommonObject
$url_internal_ticket = dol_buildpath('/ticket/card.php', 2) . '?track_id=' . $this->track_id;
$message .= "\n" . $langs->transnoentities('TicketNotificationEmailBodyInfosTrackUrlinternal') . ' : ' . '
' . $this->track_id . ' ' . "\n";
} else {
- $url_public_ticket = ($conf->global->TICKETS_URL_PUBLIC_INTERFACE ? $conf->global->TICKETS_URL_PUBLIC_INTERFACE . '/' : dol_buildpath('/public/ticket/view.php', 2)) . '?track_id=' . $this->track_id;
+ $url_public_ticket = ($conf->global->TICKET_URL_PUBLIC_INTERFACE ? $conf->global->TICKET_URL_PUBLIC_INTERFACE . '/' : dol_buildpath('/public/ticket/view.php', 2)) . '?track_id=' . $this->track_id;
$message .= "\n" . $langs->transnoentities('TicketNewEmailBodyInfosTrackUrlCustomer') . ' : ' . '
' . $this->track_id . ' ' . "\n";
}
$message .= "\n";
$message .= $langs->transnoentities('TicketEmailPleaseDoNotReplyToThisEmail') . "\n";
- $from = $conf->global->MAIN_INFO_SOCIETE_NOM . '<' . $conf->global->TICKETS_NOTIFICATION_EMAIL_FROM . '>';
+ $from = $conf->global->MAIN_INFO_SOCIETE_NOM . '<' . $conf->global->TICKET_NOTIFICATION_EMAIL_FROM . '>';
$replyto = $from;
// Init to avoid errors
@@ -1608,7 +1608,7 @@ class Ticket extends CommonObject
$message = dol_nl2br($message);
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$old_MAIN_MAIL_AUTOCOPY_TO = $conf->global->MAIN_MAIL_AUTOCOPY_TO;
$conf->global->MAIN_MAIL_AUTOCOPY_TO = '';
}
@@ -1622,7 +1622,7 @@ class Ticket extends CommonObject
$nb_sent++;
}
}
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$conf->global->MAIN_MAIL_AUTOCOPY_TO = $old_MAIN_MAIL_AUTOCOPY_TO;
}
}
@@ -2244,7 +2244,7 @@ class Ticket extends CommonObject
$message = dol_nl2br($message);
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$old_MAIN_MAIL_AUTOCOPY_TO = $conf->global->MAIN_MAIL_AUTOCOPY_TO;
$conf->global->MAIN_MAIL_AUTOCOPY_TO = '';
}
@@ -2276,7 +2276,7 @@ class Ticket extends CommonObject
$this->error = $mailfile->error;
//dol_syslog("Notify::send ".$this->error, LOG_ERR);
}
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$conf->global->MAIN_MAIL_AUTOCOPY_TO = $old_MAIN_MAIL_AUTOCOPY_TO;
}
}
diff --git a/htdocs/ticket/contact.php b/htdocs/ticket/contact.php
index 71b5c65b137..e96fb015c04 100644
--- a/htdocs/ticket/contact.php
+++ b/htdocs/ticket/contact.php
@@ -138,7 +138,7 @@ if ($id > 0 || !empty($track_id) || !empty($ref)) {
dol_fiche_end();
}
- if (!$user->societe_id && $conf->global->TICKETS_LIMIT_VIEW_ASSIGNED_ONLY) {
+ if (!$user->societe_id && $conf->global->TICKET_LIMIT_VIEW_ASSIGNED_ONLY) {
$object->next_prev_filter = "te.fk_user_assign = '" . $user->id . "'";
} elseif ($user->societe_id > 0) {
$object->next_prev_filter = "te.fk_soc = '" . $user->societe_id . "'";
diff --git a/htdocs/ticket/css/styles.css.php b/htdocs/ticket/css/styles.css.php
index ffcff73bb78..f8368f7e5f2 100644
--- a/htdocs/ticket/css/styles.css.php
+++ b/htdocs/ticket/css/styles.css.php
@@ -50,7 +50,7 @@ html {
html {
global->TICKETS_SHOW_MODULE_LOGO)) {
+if (! empty($conf->global->TICKET_SHOW_MODULE_LOGO)) {
print 'background: url("../public/img/bg_ticket.png") no-repeat 95% 90%;';
}
?>
diff --git a/htdocs/ticket/document.php b/htdocs/ticket/document.php
index b5ba65b9eba..e31cd98912d 100644
--- a/htdocs/ticket/document.php
+++ b/htdocs/ticket/document.php
@@ -105,7 +105,7 @@ if ($object->id)
dol_fiche_end();
}
- if (!$user->societe_id && $conf->global->TICKETS_LIMIT_VIEW_ASSIGNED_ONLY) {
+ if (!$user->societe_id && $conf->global->TICKET_LIMIT_VIEW_ASSIGNED_ONLY) {
$object->next_prev_filter = "te.fk_user_assign = '" . $user->id . "'";
} elseif ($user->societe_id > 0) {
$object->next_prev_filter = "te.fk_soc = '" . $user->societe_id . "'";
diff --git a/htdocs/ticket/history.php b/htdocs/ticket/history.php
index 59dc7fdd95d..c982acf3a3a 100644
--- a/htdocs/ticket/history.php
+++ b/htdocs/ticket/history.php
@@ -90,7 +90,7 @@ if ($action == 'view') {
accessforbidden('', 0);
}
// or for unauthorized internals users
- if (!$user->societe_id && ($conf->global->TICKETS_LIMIT_VIEW_ASSIGNED_ONLY && $object->fk_user_assign != $user->id) && !$user->rights->ticket->manage) {
+ if (!$user->societe_id && ($conf->global->TICKET_LIMIT_VIEW_ASSIGNED_ONLY && $object->fk_user_assign != $user->id) && !$user->rights->ticket->manage) {
accessforbidden('', 0);
}
@@ -102,7 +102,7 @@ if ($action == 'view') {
dol_fiche_end();
}
- if (!$user->societe_id && $conf->global->TICKETS_LIMIT_VIEW_ASSIGNED_ONLY) {
+ if (!$user->societe_id && $conf->global->TICKET_LIMIT_VIEW_ASSIGNED_ONLY) {
$object->next_prev_filter = "te.fk_user_assign = '" . $user->id . "'";
} elseif ($user->societe_id > 0) {
$object->next_prev_filter = "te.fk_soc = '" . $user->societe_id . "'";
diff --git a/htdocs/ticket/index.php b/htdocs/ticket/index.php
index ca4ec8a7005..92fe366c65c 100644
--- a/htdocs/ticket/index.php
+++ b/htdocs/ticket/index.php
@@ -139,7 +139,7 @@ if ($user->societe_id > 0) {
$sql .= " AND t.fk_soc='" . $user->societe_id . "'";
} else {
// For internals users,
- if (!empty($conf->global->TICKETS_LIMIT_VIEW_ASSIGNED_ONLY) && !$user->rights->ticket->manage) {
+ if (!empty($conf->global->TICKET_LIMIT_VIEW_ASSIGNED_ONLY) && !$user->rights->ticket->manage) {
$sql .= " AND t.fk_user_assign=" . $user->id;
}
}
@@ -283,7 +283,7 @@ if ($user->societe_id > 0) {
$sql .= " AND t.fk_soc='" . $user->societe_id . "'";
} else {
// Restricted to assigned user only
- if ($conf->global->TICKETS_LIMIT_VIEW_ASSIGNED_ONLY && !$user->rights->ticket->manage) {
+ if ($conf->global->TICKET_LIMIT_VIEW_ASSIGNED_ONLY && !$user->rights->ticket->manage) {
$sql .= " AND t.fk_user_assign=" . $user->id;
}
}
diff --git a/htdocs/ticket/list.php b/htdocs/ticket/list.php
index b3df986cde7..cc3291a5e00 100644
--- a/htdocs/ticket/list.php
+++ b/htdocs/ticket/list.php
@@ -216,7 +216,7 @@ foreach($search as $key => $val)
if ($search_all) $sql.= natural_search(array_keys($fieldstosearchall), $search_all);
if ($search_fk_soc) $sql.= natural_search('fk_soc', $search_fk_soc);
if ($search_fk_project) $sql.= natural_search('fk_project', $search_fk_project);
-if (!$user->societe_id && ($mode == "my_assign" || (!$user->admin && $conf->global->TICKETS_LIMIT_VIEW_ASSIGNED_ONLY))) {
+if (!$user->societe_id && ($mode == "my_assign" || (!$user->admin && $conf->global->TICKET_LIMIT_VIEW_ASSIGNED_ONLY))) {
$sql.= " AND t.fk_user_assign=".$user->id;
}
diff --git a/htdocs/public/ticket/create_ticket.php b/htdocs/public/ticket/create_ticket.php
index 0cd27ff0e73..066471fddff 100644
--- a/htdocs/public/ticket/create_ticket.php
+++ b/htdocs/public/ticket/create_ticket.php
@@ -102,7 +102,7 @@ if ($action == 'create_ticket' && GETPOST('add_ticket')) {
$contacts = $object->searchContactByEmail($origin_email);
// Option to require email exists to create ticket
- if (!empty($conf->global->TICKETS_EMAIL_MUST_EXISTS) && !$contacts[0]->socid) {
+ if (!empty($conf->global->TICKET_EMAIL_MUST_EXISTS) && !$contacts[0]->socid) {
$error++;
array_push($object->errors, $langs->trans("ErrorEmailMustExistToCreateTicket"));
$action = '';
@@ -203,24 +203,24 @@ if ($action == 'create_ticket' && GETPOST('add_ticket')) {
// Send email to customer
$subject = '[' . $conf->global->MAIN_INFO_SOCIETE_NOM . '] ' . $langs->transnoentities('TicketNewEmailSubject');
- $message .= ($conf->global->TICKETS_MESSAGE_MAIL_NEW ? $conf->global->TICKETS_MESSAGE_MAIL_NEW : $langs->transnoentities('TicketNewEmailBody')) . "\n\n";
+ $message .= ($conf->global->TICKET_MESSAGE_MAIL_NEW ? $conf->global->TICKET_MESSAGE_MAIL_NEW : $langs->transnoentities('TicketNewEmailBody')) . "\n\n";
$message .= $langs->transnoentities('TicketNewEmailBodyInfosTicket') . "\n";
- $url_public_ticket = ($conf->global->TICKETS_URL_PUBLIC_INTERFACE ? $conf->global->TICKETS_URL_PUBLIC_INTERFACE . '/' : dol_buildpath('/public/ticket/view.php', 2)) . '?track_id=' . $object->track_id;
+ $url_public_ticket = ($conf->global->TICKET_URL_PUBLIC_INTERFACE ? $conf->global->TICKET_URL_PUBLIC_INTERFACE . '/' : dol_buildpath('/public/ticket/view.php', 2)) . '?track_id=' . $object->track_id;
$infos_new_ticket = $langs->transnoentities('TicketNewEmailBodyInfosTrackId', '' . $object->track_id . ' ') . "\n";
$infos_new_ticket .= $langs->transnoentities('TicketNewEmailBodyInfosTrackUrl') . "\n\n";
$message .= dol_nl2br($infos_new_ticket);
- $message .= $conf->global->TICKETS_MESSAGE_MAIL_SIGNATURE ? $conf->global->TICKETS_MESSAGE_MAIL_SIGNATURE : $langs->transnoentities('TicketMessageMailSignatureText');
+ $message .= $conf->global->TICKET_MESSAGE_MAIL_SIGNATURE ? $conf->global->TICKET_MESSAGE_MAIL_SIGNATURE : $langs->transnoentities('TicketMessageMailSignatureText');
$sendto = GETPOST('email','alpha');
- $from = $conf->global->MAIN_INFO_SOCIETE_NOM . '<' . $conf->global->TICKETS_NOTIFICATION_EMAIL_FROM . '>';
+ $from = $conf->global->MAIN_INFO_SOCIETE_NOM . '<' . $conf->global->TICKET_NOTIFICATION_EMAIL_FROM . '>';
$replyto = $from;
$message = dol_nl2br($message);
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$old_MAIN_MAIL_AUTOCOPY_TO = $conf->global->MAIN_MAIL_AUTOCOPY_TO;
$conf->global->MAIN_MAIL_AUTOCOPY_TO = '';
}
@@ -231,14 +231,14 @@ if ($action == 'create_ticket' && GETPOST('add_ticket')) {
} else {
$result = $mailfile->sendfile();
}
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$conf->global->MAIN_MAIL_AUTOCOPY_TO = $old_MAIN_MAIL_AUTOCOPY_TO;
}
- // Send email to TICKETS_NOTIFICATION_EMAIL_TO
+ // Send email to TICKET_NOTIFICATION_EMAIL_TO
- $sendto = $conf->global->TICKETS_NOTIFICATION_EMAIL_TO;
+ $sendto = $conf->global->TICKET_NOTIFICATION_EMAIL_TO;
if ($sendto)
{
@@ -276,12 +276,12 @@ if ($action == 'create_ticket' && GETPOST('add_ticket')) {
$message_admin .= '' . $langs->trans('Message') . ' : ' . $object->message . '
';
$message_admin .= '' . $langs->trans('SeeThisTicketIntomanagementInterface') . '
';
- $from = $conf->global->MAIN_INFO_SOCIETE_NOM . '<' . $conf->global->TICKETS_NOTIFICATION_EMAIL_FROM . '>';
+ $from = $conf->global->MAIN_INFO_SOCIETE_NOM . '<' . $conf->global->TICKET_NOTIFICATION_EMAIL_FROM . '>';
$replyto = $from;
$message_admin = dol_nl2br($message_admin);
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$old_MAIN_MAIL_AUTOCOPY_TO = $conf->global->MAIN_MAIL_AUTOCOPY_TO;
$conf->global->MAIN_MAIL_AUTOCOPY_TO = '';
}
@@ -292,7 +292,7 @@ if ($action == 'create_ticket' && GETPOST('add_ticket')) {
} else {
$result = $mailfile->sendfile();
}
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$conf->global->MAIN_MAIL_AUTOCOPY_TO = $old_MAIN_MAIL_AUTOCOPY_TO;
}
}
@@ -329,7 +329,7 @@ llxHeaderTicket($langs->trans("CreateTicket"), "", 0, 0, $arrayofjs, $arrayofcss
$form = new Form($db);
$formticket = new FormTicket($db);
-if (!$conf->global->TICKETS_ENABLE_PUBLIC_INTERFACE) {
+if (!$conf->global->TICKET_ENABLE_PUBLIC_INTERFACE) {
print '' . $langs->trans('TicketPublicInterfaceForbidden') . '
';
$db->close();
exit();
diff --git a/htdocs/ticket/class/actions_ticket.class.php b/htdocs/ticket/class/actions_ticket.class.php
index fe4ea373e1e..72e010eb1f4 100644
--- a/htdocs/ticket/class/actions_ticket.class.php
+++ b/htdocs/ticket/class/actions_ticket.class.php
@@ -195,14 +195,14 @@ class ActionsTicket
}
// Auto assign user
- if ($conf->global->TICKETS_AUTO_ASSIGN_USER_CREATE) {
+ if ($conf->global->TICKET_AUTO_ASSIGN_USER_CREATE) {
$result = $object->assignUser($user, $user->id, 1);
$object->add_contact($user->id, "SUPPORTTEC", 'internal');
}
// Auto assign contrat
$contractid = 0;
- if ($conf->global->TICKETS_AUTO_ASSIGN_CONTRACT_CREATE) {
+ if ($conf->global->TICKET_AUTO_ASSIGN_CONTRACT_CREATE) {
$contrat = new Contrat($this->db);
$contrat->socid = $object->fk_soc;
$list = $contrat->getListOfContracts();
@@ -217,7 +217,7 @@ class ActionsTicket
}
// Auto create fiche intervention
- if ($conf->global->TICKETS_AUTO_CREATE_FICHINTER_CREATE)
+ if ($conf->global->TICKET_AUTO_CREATE_FICHINTER_CREATE)
{
$fichinter = new Fichinter($this->db);
$fichinter->socid = $object->fk_soc;
@@ -637,7 +637,7 @@ class ActionsTicket
$subject = GETPOST('subject') ? GETPOST('subject') : '[' . $label_title . '- ticket #' . $object->track_id . '] ' . $langs->trans('TicketNewMessage');
$message_intro = $langs->trans('TicketNotificationEmailBody', "#" . $object->id);
- $message_signature = GETPOST('mail_signature') ? GETPOST('mail_signature') : $conf->global->TICKETS_MESSAGE_MAIL_SIGNATURE;
+ $message_signature = GETPOST('mail_signature') ? GETPOST('mail_signature') : $conf->global->TICKET_MESSAGE_MAIL_SIGNATURE;
$message = $langs->trans('TicketMessageMailIntroText');
$message .= "\n\n";
@@ -673,9 +673,9 @@ class ActionsTicket
$message .= "\n" . $langs->trans('TicketNotificationEmailBodyInfosTrackUrlinternal') . ' : ' . '
' . $object->track_id . ' ' . "\n";
// Add global email address recipient
- // altairis: use new TICKETS_NOTIFICATION_EMAIL_TO configuration variable
- if ($conf->global->TICKETS_NOTIFICATION_ALSO_MAIN_ADDRESS && !in_array($conf->global->TICKETS_NOTIFICATION_EMAIL_TO, $sendto)) {
- if(!empty($conf->global->TICKETS_NOTIFICATION_EMAIL_TO)) $sendto[] = $conf->global->TICKETS_NOTIFICATION_EMAIL_TO;
+ // altairis: use new TICKET_NOTIFICATION_EMAIL_TO configuration variable
+ if ($conf->global->TICKET_NOTIFICATION_ALSO_MAIN_ADDRESS && !in_array($conf->global->TICKET_NOTIFICATION_EMAIL_TO, $sendto)) {
+ if(!empty($conf->global->TICKET_NOTIFICATION_EMAIL_TO)) $sendto[] = $conf->global->TICKET_NOTIFICATION_EMAIL_TO;
}
// altairis: dont try to send email if no recipient
@@ -709,8 +709,8 @@ class ActionsTicket
$label_title = empty($conf->global->MAIN_APPLICATION_TITLE) ? $mysoc->name : $conf->global->MAIN_APPLICATION_TITLE;
$subject = GETPOST('subject') ? GETPOST('subject') : '[' . $label_title . '- ticket #' . $object->track_id . '] ' . $langs->trans('TicketNewMessage');
- $message_intro = GETPOST('mail_intro') ? GETPOST('mail_intro') : $conf->global->TICKETS_MESSAGE_MAIL_INTRO;
- $message_signature = GETPOST('mail_signature') ? GETPOST('mail_signature') : $conf->global->TICKETS_MESSAGE_MAIL_SIGNATURE;
+ $message_intro = GETPOST('mail_intro') ? GETPOST('mail_intro') : $conf->global->TICKET_MESSAGE_MAIL_INTRO;
+ $message_signature = GETPOST('mail_signature') ? GETPOST('mail_signature') : $conf->global->TICKET_MESSAGE_MAIL_SIGNATURE;
// We put intro after
$message = GETPOST('message');
@@ -731,9 +731,9 @@ class ActionsTicket
}
// If public interface is not enable, use link to internal page into mail
- $url_public_ticket = (!empty($conf->global->TICKETS_ENABLE_PUBLIC_INTERFACE) ?
- (!empty($conf->global->TICKETS_URL_PUBLIC_INTERFACE) ?
- $conf->global->TICKETS_URL_PUBLIC_INTERFACE . '/view.php' :
+ $url_public_ticket = (!empty($conf->global->TICKET_ENABLE_PUBLIC_INTERFACE) ?
+ (!empty($conf->global->TICKET_URL_PUBLIC_INTERFACE) ?
+ $conf->global->TICKET_URL_PUBLIC_INTERFACE . '/view.php' :
dol_buildpath('/public/ticket/view.php', 2)
) :
dol_buildpath('/ticket/card.php', 2)
@@ -757,8 +757,8 @@ class ActionsTicket
}
// altairis: Add global email address reciepient
- if ($conf->global->TICKETS_NOTIFICATION_ALSO_MAIN_ADDRESS && !in_array($conf->global->TICKETS_NOTIFICATION_EMAIL_TO, $sendto)) {
- if(!empty($conf->global->TICKETS_NOTIFICATION_EMAIL_TO)) $sendto[] = $conf->global->TICKETS_NOTIFICATION_EMAIL_TO;
+ if ($conf->global->TICKET_NOTIFICATION_ALSO_MAIN_ADDRESS && !in_array($conf->global->TICKET_NOTIFICATION_EMAIL_TO, $sendto)) {
+ if(!empty($conf->global->TICKET_NOTIFICATION_EMAIL_TO)) $sendto[] = $conf->global->TICKET_NOTIFICATION_EMAIL_TO;
}
// altairis: dont try to send email when no recipient
@@ -867,11 +867,11 @@ class ActionsTicket
$message .= "\n\n";
- $message_signature = GETPOST('mail_signature') ? GETPOST('mail_signature') : $conf->global->TICKETS_MESSAGE_MAIL_SIGNATURE;
+ $message_signature = GETPOST('mail_signature') ? GETPOST('mail_signature') : $conf->global->TICKET_MESSAGE_MAIL_SIGNATURE;
// Add global email address reciepient
- if ($conf->global->TICKETS_NOTIFICATION_ALSO_MAIN_ADDRESS && !in_array($conf->global->TICKETS_NOTIFICATION_EMAIL_FROM, $sendto)) {
- $sendto[] = $conf->global->TICKETS_NOTIFICATION_EMAIL_FROM;
+ if ($conf->global->TICKET_NOTIFICATION_ALSO_MAIN_ADDRESS && !in_array($conf->global->TICKET_NOTIFICATION_EMAIL_FROM, $sendto)) {
+ $sendto[] = $conf->global->TICKET_NOTIFICATION_EMAIL_FROM;
}
$this->sendTicketMessageByEmail($subject, $message, '', $sendto);
@@ -893,7 +893,7 @@ class ActionsTicket
$message .= GETPOST('message');
$message .= "\n\n";
- $message_signature = GETPOST('mail_signature') ? GETPOST('mail_signature') : $conf->global->TICKETS_MESSAGE_MAIL_SIGNATURE;
+ $message_signature = GETPOST('mail_signature') ? GETPOST('mail_signature') : $conf->global->TICKET_MESSAGE_MAIL_SIGNATURE;
foreach ($external_contacts as $key => $info_sendto) {
if ($info_sendto['email'] != '') {
$sendto[] = trim($info_sendto['firstname'] . " " . $info_sendto['lastname']) . " <" . $info_sendto['email'] . ">";
@@ -903,7 +903,7 @@ class ActionsTicket
$message .= (!empty($recipient) ? $langs->trans('TicketNotificationRecipient') . ' : ' . $recipient . "\n" : '');
}
- $url_public_ticket = ($conf->global->TICKETS_URL_PUBLIC_INTERFACE ? $conf->global->TICKETS_URL_PUBLIC_INTERFACE . '/view.php' : dol_buildpath('/public/ticket/view.php', 2)) . '?track_id=' . $object->track_id;
+ $url_public_ticket = ($conf->global->TICKET_URL_PUBLIC_INTERFACE ? $conf->global->TICKET_URL_PUBLIC_INTERFACE . '/view.php' : dol_buildpath('/public/ticket/view.php', 2)) . '?track_id=' . $object->track_id;
$message .= "\n\n" . $langs->trans('TicketNewEmailBodyInfosTrackUrlCustomer') . ' : ' . $url_public_ticket . "\n";
// Add signature
@@ -1310,14 +1310,14 @@ class ActionsTicket
*
* @param string $subject Email subject
* @param string $message Email message
* @param int $send_internal_cc Receive a copy on internal email ($conf->global->TICKETS_NOTIFICATION_EMAIL_FROM)
* @param array $array_receiver Array of receiver. exemple array('name' => 'John Doe', 'email' => 'john@doe.com', etc...)
*/
public function sendTicketMessageByEmail($subject, $message, $send_internal_cc = 0, $array_receiver = array())
{
global $conf, $langs;
- if ($conf->global->TICKETS_DISABLE_ALL_MAILS) {
+ if ($conf->global->TICKET_DISABLE_ALL_MAILS) {
dol_syslog(get_class($this) . '::sendTicketMessageByEmail: Emails are disable into ticket setup by option TICKETSUP_DISABLE_ALL_MAILS', LOG_WARNING);
return '';
}
@@ -1337,10 +1337,10 @@ class ActionsTicket
}
if ($send_internal_cc) {
- $sendtocc = $conf->global->TICKETS_NOTIFICATION_EMAIL_FROM;
+ $sendtocc = $conf->global->TICKET_NOTIFICATION_EMAIL_FROM;
}
- $from = $conf->global->TICKETS_NOTIFICATION_EMAIL_FROM;
+ $from = $conf->global->TICKET_NOTIFICATION_EMAIL_FROM;
if (is_array($array_receiver) && count($array_receiver) > 0) {
foreach ($array_receiver as $key => $receiver) {
// Create form object
@@ -1355,7 +1355,7 @@ class ActionsTicket
$message_to_send = dol_nl2br($message);
// Envoi du mail
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$old_MAIN_MAIL_AUTOCOPY_TO = $conf->global->MAIN_MAIL_AUTOCOPY_TO;
$conf->global->MAIN_MAIL_AUTOCOPY_TO = '';
}
@@ -1377,7 +1377,7 @@ class ActionsTicket
}
}
}
- if (!empty($conf->global->TICKETS_DISABLE_MAIL_AUTOCOPY_TO)) {
+ if (!empty($conf->global->TICKET_DISABLE_MAIL_AUTOCOPY_TO)) {
$conf->global->MAIN_MAIL_AUTOCOPY_TO = $old_MAIN_MAIL_AUTOCOPY_TO;
}
}
@@ -1310,14 +1310,14 @@ class ActionsTicket
* @param string $subject Email subject
* @param string $message Email message
- * @param int $send_internal_cc Receive a copy on internal email ($conf->global->TICKETS_NOTIFICATION_EMAIL_FROM)
+ * @param int $send_internal_cc Receive a copy on internal email ($conf->global->TICKET_NOTIFICATION_EMAIL_FROM)
* @param array $array_receiver Array of receiver. exemple array('name' => 'John Doe', 'email' => 'john@doe.com', etc...)
*/